@@ -271,3 +271,36 @@ def get_ssm_config_for_parameter(account_ssm_param, required_parameter_name):
             "name": account_ssm_param.get("name"),
             "parameter_name": required_parameter_name,
         }
+
+
+@functools.lru_cache(maxsize=32)
+def get_initialiser_stack_tags():
+    with betterboto_client.ClientContextManager("ssm") as ssm:
+        try:
+            response = ssm.get_parameter(
+                Name=constants.INITIALISER_STACK_NAME_SSM_PARAMETER
+            )
+            initialiser_stack_name = response.get("Parameter").get("Value")
+            with betterboto_client.ClientContextManager(
+                "cloudformation"
+            ) as cloudformation:
+                paginator = cloudformation.get_paginator("describe_stacks")
+                for page in paginator.paginate(StackName=initialiser_stack_name,):
+                    for stack in page.get("Stacks", []):
+                        if stack.get("StackStatus") in [
+                            "CREATE_IN_PROGRESS",
+                            "CREATE_COMPLETE",
+                            "UPDATE_IN_PROGRESS",
+                            "UPDATE_COMPLETE_CLEANUP_IN_PROGRESS",
+                            "UPDATE_COMPLETE",
+                        ]:
+                            return stack.get("Tags")
+                        else:
+                            raise Exception(
+                                f"Initialiser stack: {initialiser_stack_name} in state: {stack.get('StackStatus')}"
+                            )
+        except ssm.exceptions.ParameterNotFound:
+            logger.warning(
+                f"Could not find SSM parameter: {constants.INITIALISER_STACK_NAME_SSM_PARAMETER}, do not know the tags to use"
+            )
+            return []
